@@ -2,7 +2,7 @@
 #
 # The MIT License (MIT)
 #
-# Copyright (c) Tavendo GmbH
+# Copyright (c) Crossbar.io Technologies GmbH
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -31,7 +31,7 @@ import six
 
 from autobahn.wamp import protocol
 from autobahn.wamp.types import ComponentConfig
-from autobahn.websocket.protocol import parseWsUrl
+from autobahn.websocket.util import parse_url
 from autobahn.asyncio.websocket import WampWebSocketClientFactory
 
 try:
@@ -78,9 +78,9 @@ class ApplicationRunner(object):
     connecting to a WAMP router.
     """
 
-    def __init__(self, url, realm, extra=None, serializers=None,
-                 debug=False, debug_app=False,
-                 ssl=None):
+    log = txaio.make_logger()
+
+    def __init__(self, url, realm, extra=None, serializers=None, ssl=None):
         """
         :param url: The WebSocket URL of the WAMP router to connect to (e.g. `ws://somehost.com:8090/somepath`)
         :type url: unicode
@@ -95,12 +95,6 @@ class ApplicationRunner(object):
            Serializers must implement :class:`autobahn.wamp.interfaces.ISerializer`.
         :type serializers: list
 
-        :param debug: Turn on low-level debugging.
-        :type debug: bool
-
-        :param debug_app: Turn on app-level debugging.
-        :type debug_app: bool
-
         :param ssl: An (optional) SSL context instance or a bool. See
            the documentation for the `loop.create_connection` asyncio
            method, to which this value is passed as the ``ssl=``
@@ -114,8 +108,6 @@ class ApplicationRunner(object):
         self.realm = realm
         self.extra = extra or dict()
         self.serializers = serializers
-        self.debug = debug
-        self.debug_app = debug_app
         self.ssl = ssl
 
     def run(self, make):
@@ -131,14 +123,16 @@ class ApplicationRunner(object):
             cfg = ComponentConfig(self.realm, self.extra)
             try:
                 session = make(cfg)
-            except Exception:
-                self.log.failure("App session could not be created! ")
-                asyncio.get_event_loop().stop()
+            except Exception as e:
+                self.log.error('ApplicationSession could not be instantiated: {}'.format(e))
+                loop = asyncio.get_event_loop()
+                if loop.is_running():
+                    loop.stop()
+                raise
             else:
-                session.debug_app = self.debug_app
                 return session
 
-        isSecure, host, port, resource, path, params = parseWsUrl(self.url)
+        isSecure, host, port, resource, path, params = parse_url(self.url)
 
         if self.ssl is None:
             ssl = isSecure
@@ -151,8 +145,7 @@ class ApplicationRunner(object):
             ssl = self.ssl
 
         # 2) create a WAMP-over-WebSocket transport client factory
-        transport_factory = WampWebSocketClientFactory(create, url=self.url, serializers=self.serializers,
-                                                       debug=self.debug)
+        transport_factory = WampWebSocketClientFactory(create, url=self.url, serializers=self.serializers)
 
         # 3) start the client
         loop = asyncio.get_event_loop()
@@ -161,6 +154,9 @@ class ApplicationRunner(object):
         coro = loop.create_connection(transport_factory, host, port, ssl=ssl)
         (transport, protocol) = loop.run_until_complete(coro)
 
+        # start logging
+        txaio.start_logging(level='info')
+
         try:
             loop.add_signal_handler(signal.SIGTERM, loop.stop)
         except NotImplementedError:
